/****************
Arlington Web Services, Inc.
Copyright (C) 2007
All rights reserved worldwide
// YahooSoap.h
**************/

#ifndef YAHOO_SOAP_H
#define YAHOO_SOAP_H

/***********************
October 9, 2007

A DLL will get information from a web server program and return the information to 
interface.exe (INTERFACE).  The DLL will receive information from the INTERFACE.  

The INTERFACE program will run in the System Tray

The install process will create the following registry entries:
HKEY_LOCAL_MACHINE\SOFTWARE\Arlington\Common\Install Directory
HKEY_LOCAL_MACHINE\SOFTWARE\Arlington\Common\Settings Executable
HKEY_LOCAL_MACHINE\SOFTWARE\Arlington\Common\Interface Not Running Message
HKEY_LOCAL_MACHINE\SOFTWARE\Arlington\Common\Pending Message Folder

The INTERFACE program will create the following registry entry when loaded:
HKEY_LOCAL_MACHINE\SOFTWARE\Arlington\Common\Interface Executable

The DLL can get the handle for the INTERFACE window by using 
hwndINTERFACE = FindWindow("SpamInterfaceClass", NULL).
Not likely this will be needed.


A SenderValue is to be used when posting and sending messages.
The SenderValue will be 0xFFFF0000 when the INTERFACE is the sender.

The SenderValue for the IE EXTENSION will be in the range 
of 0x01010001 to 0x0101FFFF

The SenderValue for the Firefox EXTENSION will be in the range 
of 0x01020001 to 0x0102FFFF

The SenderValue for the Outlook Express PLUGIN will be in the range 
of 0x02010001 to 0x0201FFFF

The SenderValue for the Outlook PLUGIN will be in the range 
of 0x02020001 to 0x0202FFFF

The SenderValue for the Eudora PLUGIN will be in the range 
of 0x02030001 to 0x0203FFFF

The Yahoo SOAP functions will be in the range of 0x03010001
to 0x0301FFFF
*************************/

#include "windows.h"

#define SENDER_VALUE_IE          0x01010001   // code for IE Browser
#define SENDER_VALUE_FIREFOX     0x01020001   // code for IE Browser
#define SENDER_VALUE_OE          0x02010001   // Version 1 of extended OE Plugin
#define SENDER_VALUE_OUTLOOK     0x02020001
#define SENDER_VALUE_EUDORA      0x02030001
#define SENDER_VALUE_THUNDERBIRD 0x02040001   // Affrf September 25, 2007
#define SENDER_VALUE_INTERFACE   0xFFFF0000
#define SENDER_YAHOO_SOAP        0x03010001   // SOAP Yahoo


#define USER_FLAG_MAIL_PLUS       1
#define USER_FLAG_SPAM_GUARD_PLUS 2
#define USER_FLAG_FILTER_ACTIVE   4
#define USER_FLAG_SPAM_TO_INBOX   8
#define USER_FLAG_BLOCK_SENDER   16 

#define FLAG_IS_REPLIED         1
#define FLAG_IS_FLAGGED         2
#define FLAG_IS_READ            4
#define FLAG_IS_DRAFT           8
#define FLAG_IS_UUENCODED      16
#define FLAG_IS_FORWARDED      32
#define FLAG_IS_HAM            64
#define FLAG_IS_SPAM          128
#define FLAG_HAS_ATTACHMENT   256
#define FLAG_IN_ADDRESS_BOOK  512
#define FLAG_


typedef struct {
    int   nSize;         // sizeof(tUserData)
    int   nUserFlag;    // USER_FLAG_
    int   spamCleanupPeriod;
    LPSTR pEmail;  // We likely will want user to purchase our software for each Yahoo email address.
                   // I want to be able to fetch email address from server to compare against purchased address.
    LPSTR pName;   // Login Name
} tUserData;

typedef struct {
    int   nSize;         // sizeof(tFolder)
    LPSTR pFolderName;
    LPSTR pFolderID;
    BOOL  bSystemFile;
} tFolder;

typedef struct {
    int   nFlags;    // FLAG_
    LPSTR pFrom;
    LPSTR pFolderName;
    LPSTR pTo;
    LPSTR pSubject;
    LPSTR pID;
    LPSTR pReceivedDate;
    int   nMessageSize;
} tMessageInfo;

typedef struct {
    int   nSize;       // sizeof(tListMessages)
    int   nInfoSize;   // sizeof(tMessageInfo)
    LPSTR pAllocatedData;
    LPSTR pFolderID;
    LPSTR pFolderName;
    int   nFolderTotal;
    LPSTR pIDS;        // Allocate pointers for each ID plus one for terminating NULL.
    tMessageInfo *pMessageInfo;  // Allocates for number of Infos plus 1.  Last record to have pID = NULL.
} tListMessages;

/*
  We expect to request hundreds of Message Info records on a single Request.
  If response data for all Messages IDs and all Message Info records can be saved in a single
  allocated memory block, deleting allocating memory will be simple.
  
  The pointer pAllocatedData is to point to the single allocated block.
  
  If it is not easy to use a single block, the pAllocatedData is not needed.
*/




typedef struct {
    int   nSize;
    LPSTR pID;
    LPSTR pData;   // This may be full message or just raw header.
} tMessage;



int BBAuth(void);
// I think the "web service session ID" (WSSID) is returned.

tUserData *GetUserData(void);

tFolder *ListFolders(void);
// Each sub-folder levels will be separated by ^ characters.
// Example sub-folder:  Inbox^Review^Visited Sites
// where Review is a sub-folder under Inbox and Visited Sites is a sub-folder under Review


tListMessages *ListMessages(LPSTR pFolderID, LPSTR pFirstID, int NumbIDS, LPSTR pFirstInfo, int nNumbInfo);

tMessage *GetMessage(LPSTR pFolderID, LPSTR pID);

tMessage *GetMessageHeader(LPSTR pFolderID, LPSTR pID);

BOOL MoveMessages(LPSTR pIDS, LPSTR pFromFolderID, LPSTR pToFolderID)
// pIDS will be like: id1|id2|id3| etc.

BOOL CreateFolder(LPSTR pFolderName);
// pFolder will be like: Inbox^Review^Visited Sites

#endif /* YAHOO_SOAP_H */
